import React, { useState } from "react";
import { useNavigate } from "react-router-dom";
import PasswordEyeIcon from "d:/360ExtremeBrowserDownload/Password eye.svg";
import MailIcon from "d:/360ExtremeBrowserDownload/Mail.svg";
import FrameImage from "../assets/images/Frame201.svg";

const LoginPage = () => {
  const [showPassword, setShowPassword] = useState(false);
  const [email, setEmail] = useState("");
  const [emailError, setEmailError] = useState("");
  const navigate = useNavigate();

  const togglePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };

  const validateEmail = (email) => {
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
  };

  const handleCheckStatusClick = () => {
    if (!validateEmail(email)) {
      setEmailError("Please enter a valid email address.");
      return;
    }
    navigate("/status");
  };

  return (
    <div className="flex flex-col items-center justify-center min-h-screen bg-[#E9FAFF] py-10 px-6">
      <h1 className="absolute top-[130.5px] left-[450px] text-[48.31px] font-bold text-[#030A1E] leading-none">OMPOI - Seller</h1>
      <div className="bg-white flex flex-row w-[85%] max-w-6xl rounded-3xl shadow-xl overflow-hidden border border-gray-200 p-10 relative">
        {/* Left Side - Illustration */}
        <div className="hidden md:flex md:w-1/2 items-center justify-center p-6">
          <img src={FrameImage} alt="Illustration" className="w-[90%] h-auto" />
        </div>

        {/* Vertical Divider */}
        <div className="absolute top-[10%] left-[50%] w-[2px] h-[80%] bg-[#E2E7EE]"></div>

        {/* Right Side - Form */}
        <div className="w-full md:w-1/2 flex flex-col justify-center px-4 md:px-8 py-6 relative">
          <h2 className="text-2xl md:text-3xl font-semibold text-gray-900 mb-6 text-center md:text-">Check Status</h2>
          
          <div className="mb-4 w-full relative">
            <label htmlFor="email" className="text-[12px] md:text-[18px] text-[#45505F] p-[0.5px] bg-white relative top-1 left-4 px-1">Email ID</label>
            <input
              type="email"
              id="email"
              placeholder="Enter Email ID"
              value={email}
              onChange={(e) => setEmail(e.target.value)}
              className="w-full p-2 md:p-3 border border-[#C4CFDE] rounded-[12px] text-[12px] md:text-[18px] focus:outline-none"
              required
            />
            <img src={MailIcon} alt="Mail Icon" className="absolute right-3 top-8 md:top-10 w-5 h-5" />
            {emailError && <p className="text-red-500 text-sm mt-1">{emailError}</p>}
          </div>
          
          {/* Password Input */}
          <div className="mb-4 w-full relative">
            <label htmlFor="password" className="text-[12px] md:text-[18px] text-[#45505F] p-[0.5px] bg-white relative top-1 left-4 px-1">Password</label>
            <input
              type={showPassword ? "text" : "password"}
              id="password"
              placeholder="Enter your password"
              className="w-full p-2 md:p-3 border border-[#C4CFDE] rounded-[12px] text-[12px] md:text-[18px] focus:outline-none"
              required
            />
            <img
              src={PasswordEyeIcon}
              alt="Password Eye Icon"
              className="absolute right-3 top-5 md:top-10 w-5 h-5 cursor-pointer"
              onClick={togglePasswordVisibility}
            />
          </div>

          <div className="flex flex-col md:flex-row justify-between text-sm mb-6">
            <span className="text-gray-900 font-semibold cursor-pointer text-center md:text-left">Forgot Password?</span>
            <span className="text-orange-400 font-semibold cursor-pointer text-center md:text-right">Create an Account</span>
          </div>
          
          <div className="flex justify-center">
            <button 
              onClick={handleCheckStatusClick}
              className="w-46 px-7 py-1 md:py-2 rounded-[34.76px] outline outline-2 outline-offset-[-1.07px] outline-[#FFBD69] inline-flex justify-center items-center gap-3.5 bg-transparent text-slate-950 text-xl md:text-2xl font-medium font-['Montserrat'] leading-loose tracking-tight hover:bg-orange-500 hover:text-white transition"
            >
              Check Status
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default LoginPage;
